/*--------------------------------------------------------------------------+
|                                                                          |
|                                                                          |
| Copyright 2017 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.transform;

import org.fortiss.af3.platform.raspberry.generator.executable.RaspberryPIExecutable;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.tooling.kernel.extension.ITransformationProvider;
import org.fortiss.tooling.kernel.extension.data.ITransformationContext;

/**
 * Transformation from {@link RaspberryPi} to {@link RaspberryPIExecutable}.
 * 
 * @author eder
 * @author  eder $
 *                                                                                                 18709 $
 *                                                                                                 RED Hash:
 */
public class RaspberryPITransformation implements ITransformationProvider {

	/** {@inheritDoc} */
	@Override
	public Class<?> getTargetClass() {
		return RaspberryPIExecutable.class;
	}

	/** {@inheritDoc} */
	@Override
	public boolean
			canHandleChainTransformation(Class<?> sourceClass, ITransformationContext context) {
		return RaspberryPi.class.isAssignableFrom(sourceClass);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canTransform(Object source, ITransformationContext context) {
		return source instanceof RaspberryPi;
	}

	/** {@inheritDoc} */
	@Override
	public Object transform(Object source, ITransformationContext context) {
		return new RaspberryPIExecutable((RaspberryPi)source);
	}

}
